@@ -65,7 +65,7 @@ sub AUTOLOAD {
     my $self = shift;
     return if $AUTOLOAD eq 'DESTROY';
     unless ($self->has_section($AUTOLOAD)) {
-        Carp::croak("There is no $AUTOLOAD' sction in the block.");
+        Carp::croak("There is no $AUTOLOAD' section in the block.");
     }
     $self->get_section($AUTOLOAD);
 }
